package com.zhentao.service.impl;

import cn.hutool.core.util.IdUtil;
import com.zhentao.domain.UserLogin;
import com.zhentao.domain.WechatAuthResponse;
import com.zhentao.dto.Result;
import com.zhentao.dto.user.WeLogin;
import com.zhentao.service.UserLoginService;
import com.zhentao.service.WeXinLoginService;
import com.zhentao.tool.TokenUtils;
import com.zhentao.tool.WechatLoginUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.HashMap;

@Service
public class WeXinLoginImpl implements WeXinLoginService {
    @Autowired
    private StringRedisTemplate stringRedisTemplate;
    @Autowired
    private UserLoginService service;
    @Override
    public Result wechatLogin(WeLogin weLogin) {
        try {
            WechatAuthResponse authResponse = WechatLoginUtil.getAuthInfo(weLogin.getCode());
            if (authResponse.getErrcode() == null) {
                // 登录成功，生成自己的登录态（如JWT token）
                String token = generateToken(authResponse.getOpenid());
//                将token设置在Redis中
                stringRedisTemplate.opsForValue().set(authResponse.getOpenid(),authResponse.toString());
                HashMap<String, Object> map = new HashMap<>();
                map.put("token",token);
                map.put("openid",authResponse);
                UserLogin userLogin = new UserLogin();
//                设置一个id
                long l = IdUtil.getSnowflake(1, 1).nextId();
                userLogin.setId(l);
                userLogin.setOpenId(authResponse.getOpenid());
                userLogin.setSessionKey(authResponse.getSession_key());
                userLogin.setNickName(weLogin.getWxLoginDto().getNickName());
                userLogin.setAvatar(weLogin.getWxLoginDto().getAvatarUrl());
                userLogin.setGender(weLogin.getWxLoginDto().getGender());
                service.save(userLogin);
                return Result.OK("登录成功",map);
            } else {
                // 登录失败，返回错误信息
                return Result.ERR("登录失败",authResponse.getErrmsg());
            }
        } catch (Exception e) {
            e.printStackTrace();
            return Result.ERR("登录失败",null);
        }
    }
    private String generateToken(String openid) {
        // 这里可以使用JWT或其他方式生成token
        String jwtToken = TokenUtils.createJwtToken(openid);
        return jwtToken;
    }
}
